<?php
/**
 * StoryYellers Dynamic Styles
 *
 * @package StoryYellers
 */

function storyyellers_dynamic_css()
{

    $storyyellers_default = storyyellers_get_default_theme_options();
    $background_color = get_theme_mod('background_color', $storyyellers_default['background_color']);

    $background_color = '#' . str_replace("#", "", $background_color);

    $storyyellers_header_text_color = get_theme_mod('storyyellers_header_text_color', $storyyellers_default['storyyellers_header_text_color']);

    $homepage_cta_text_color = get_theme_mod('homepage_cta_text_color', $storyyellers_default['homepage_cta_text_color']);
    $category_title_text_color = get_theme_mod('category_title_text_color', $storyyellers_default['category_title_text_color']);

    $storyyellers_primary_color = get_theme_mod('storyyellers_primary_color', $storyyellers_default['storyyellers_primary_color']);
    $storyyellers_secondary_color = get_theme_mod('storyyellers_secondary_color', $storyyellers_default['storyyellers_secondary_color']);
    $storyyellers_general_color = get_theme_mod('storyyellers_general_color', $storyyellers_default['storyyellers_general_color']);


    $storyyellers_category_colors = get_theme_mod('storyyellers_category_colors', $storyyellers_default['storyyellers_category_colors']);

    echo "<style type='text/css' media='all'>"; ?>

    <?php
    if ($storyyellers_category_colors) {
        $storyyellers_category_colors = json_decode($storyyellers_category_colors);
        foreach ($storyyellers_category_colors as $storyyellers_category_color) {
            if (isset($storyyellers_category_color->category) && $storyyellers_category_color->category && isset($storyyellers_category_color->category_color) && $storyyellers_category_color->category_color) { ?>

                .storyyellers-cat-color-<?php echo esc_attr($storyyellers_category_color->category); ?>{
                background-color: <?php echo esc_attr($storyyellers_category_color->category_color); ?> !important;
                }

                <?php
            }
        }
    } ?>

    body.theme-color-schema,
    .preloader,
    .floating-post-navigation .floating-navigation-label,
    .header-searchbar-inner,
    .offcanvas-wraper{
    background-color: <?php echo esc_attr($background_color); ?>;
    }
    body.theme-color-schema,
    body, button, input, select, optgroup, textarea,
    .floating-post-navigation .floating-navigation-label,
    .header-searchbar-inner,
    .offcanvas-wraper{
    color: <?php echo esc_attr($storyyellers_general_color); ?>;
    }

    .preloader .loader-circles span{
    background: <?php echo esc_attr($storyyellers_general_color); ?>;
    }

    .theme-main-banner{
    color: <?php echo esc_attr($storyyellers_header_text_color); ?>;
    }

    @media only screen and (min-width: 992px){
    .enabled-transparent-menu .theme-header,
    .enabled-transparent-menu .theme-header .navbar-control{
    color: <?php echo esc_attr($storyyellers_header_text_color); ?>;
    }
    }

    .categories-panel .theme-block-title{
    color: <?php echo esc_attr($category_title_text_color); ?>;
    }

    .theme-block-cta .cta-panel{
    color: <?php echo esc_attr($homepage_cta_text_color); ?>;
    }

    a{
    color: <?php echo esc_attr($storyyellers_primary_color); ?>;
    }

    body .site-navigation .primary-menu > li > a:before,
    body .site-navigation .primary-menu > li > a:after,
    body .site-navigation .primary-menu > li > a:after,
    body .site-navigation .primary-menu > li > a:hover:before,
    body .entry-thumbnail .trend-item,
    body .category-widget-header .post-count,
    body .theme-meta-categories a:hover,
    body .theme-meta-categories a:focus{
    background: <?php echo esc_attr($storyyellers_secondary_color); ?>;
    }

    body a:hover,
    body a:focus,
    body .footer-credits a:hover,
    body .footer-credits a:focus,
    body .widget a:hover,
    body .widget a:focus {
    color: <?php echo esc_attr($storyyellers_secondary_color); ?>;
    }
    body input[type="text"]:hover,
    body input[type="text"]:focus,
    body input[type="password"]:hover,
    body input[type="password"]:focus,
    body input[type="email"]:hover,
    body input[type="email"]:focus,
    body input[type="url"]:hover,
    body input[type="url"]:focus,
    body input[type="date"]:hover,
    body input[type="date"]:focus,
    body input[type="month"]:hover,
    body input[type="month"]:focus,
    body input[type="time"]:hover,
    body input[type="time"]:focus,
    body input[type="datetime"]:hover,
    body input[type="datetime"]:focus,
    body input[type="datetime-local"]:hover,
    body input[type="datetime-local"]:focus,
    body input[type="week"]:hover,
    body input[type="week"]:focus,
    body input[type="number"]:hover,
    body input[type="number"]:focus,
    body input[type="search"]:hover,
    body input[type="search"]:focus,
    body input[type="tel"]:hover,
    body input[type="tel"]:focus,
    body input[type="color"]:hover,
    body input[type="color"]:focus,
    body textarea:hover,
    body textarea:focus,
    button:focus,
    body .button:focus,
    body .wp-block-button__link:focus,
    body .wp-block-file__button:focus,
    body input[type="button"]:focus,
    body input[type="reset"]:focus,
    body input[type="submit"]:focus,
    body .theme-meta-categories a:hover,
    body .theme-meta-categories a:focus{
    border-color:  <?php echo esc_attr($storyyellers_secondary_color); ?>;
    }
    body .theme-page-vitals:after {
    border-right-color:  <?php echo esc_attr($storyyellers_secondary_color); ?>;
    }
    body a:focus,
    body .theme-action-control:focus > .action-control-trigger,
    body .submenu-toggle:focus > .btn__content{
    outline-color:  <?php echo esc_attr($storyyellers_secondary_color); ?>;
    }
    <?php echo "</style>";
}

add_action('wp_head', 'storyyellers_dynamic_css', 100);

/**
 * Sanitizing Hex color function.
 */
function storyyellers_sanitize_hex_color($color)
{

    if ('' === $color)
        return '';
    if (preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color))
        return $color;

}