<?php
/**
 * Custom Functions.
 *
 * @package StoryYellers
 */

if( !function_exists( 'storyyellers_header_image_section' ) ) :

    function storyyellers_header_image_section(){
        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_header_banner = get_theme_mod( 'ed_header_banner', $storyyellers_default['ed_header_banner'] );

        if ($ed_header_banner) {
            $header_banner_title = get_theme_mod( 'header_banner_title',$storyyellers_default['header_banner_title'] );
            $header_banner_sub_title = get_theme_mod( 'header_banner_sub_title',$storyyellers_default['header_banner_sub_title'] );
            $header_banner_description = get_theme_mod( 'header_banner_description',$storyyellers_default['header_banner_description'] );
            $header_banner_button_label = get_theme_mod( 'header_banner_button_label',$storyyellers_default['header_banner_button_label'] );
            $header_banner_button_link = get_theme_mod( 'header_banner_button_link',$storyyellers_default['header_banner_button_link'] );
            $ed_open_link_new_tab = get_theme_mod( 'ed_open_link_new_tab',$storyyellers_default['ed_open_link_new_tab'] );
            $ed_header_banner_overlay = get_theme_mod( 'ed_header_banner_overlay',$storyyellers_default['ed_header_banner_overlay'] );
            $header_image_url = get_header_image()
            ?>
            
            <div class="theme-block theme-block-banner <?php if($header_image_url){ echo 'data-bg'; }?>" data-background="<?php echo esc_url($header_image_url); ?>">
                <?php if ($ed_header_banner_overlay) { ?>
                    <div class="data-bg-overlay"></div>
                <?php } ?>
                <div class="wrapper">
                    <div class="theme-main-banner">
                        <div class="wrapper-inner">
                            <div class="column column-12 column-sm-12">
                                <div class="main-banner-details">
                                    <h2 class="main-banner-title alt-font"><?php echo esc_html($header_banner_title); ?></h2>
                                    <h3 class="main-banner-subtitle"><?php echo esc_html($header_banner_sub_title); ?></h3>
                                    <div class="main-banner-description">
                                        <?php echo wp_kses_post($header_banner_description); ?>
                                    </div>

                                    <?php
                                    if ($header_banner_button_label) { ?>
                                        <div class="theme-block-link">
                                            <a href="<?php echo esc_url($header_banner_button_link); ?>" class="theme-button theme-button-large" <?php if($ed_open_link_new_tab){ ?>target="_blank"<?php } ?>>
                                                <span><?php echo esc_html($header_banner_button_label); ?></span>
                                                <span><?php storyyellers_the_theme_svg('arrow-right'); ?></span>
                                            </a>
                                        </div>
                                    <?php } ?>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }
    }

endif;

if( !function_exists( 'storyyellers_category_section' ) ) :

    function storyyellers_category_section(){
        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_category_section = get_theme_mod( 'ed_category_section', $storyyellers_default['ed_category_section'] );
        $ed_category_description = get_theme_mod( 'ed_category_description', $storyyellers_default['ed_category_description'] );
        if ($ed_category_section) { ?>
            <div class="theme-block theme-block-categories">
                <div class="wrapper">
                    <div class="theme-categories-panels">
                        <div class="wrapper-inner">
                            <?php for ($i=1; $i <= 3; $i++) { 
                                $storyyellers_get_cat_id = absint(get_theme_mod('select_category_for_cat_list_'.$i));
                                $twp_term_image = get_term_meta( $storyyellers_get_cat_id, 'twp-term-featured-image', true );
                                $twp_cat_link = get_category_link($storyyellers_get_cat_id);
                                $twp_cat_description = category_description($storyyellers_get_cat_id);
                                ?>
                                    <div class="column column-4 column-sm-12">
                                        <div class="categories-panel">

                                            <div class="categories-panel-header">
                                                <div class="category-panel-image <?php if ($twp_term_image){ echo 'data-bg data-bg-small';} ?>" data-background="<?php echo esc_url($twp_term_image); ?>">
                                                    <?php if ( get_theme_mod('ed_category_image_overlay') == 1) { ?>
                                                        <div class="data-bg-overlay"></div>
                                                    <?php } ?>
                                                    
                                                </div>
                                            </div>

                                            <div class="categories-panel-content">
                                                <h2 class="theme-block-title secondary-font">
                                                    <a href="<?php echo esc_url($twp_cat_link); ?>">
                                                        <?php echo esc_html(get_cat_name( $storyyellers_get_cat_id));?>
                                                    </a>
                                                </h2>
                                                <?php if (($ed_category_description == 1) && !empty($twp_cat_description)) { ?>
                                                    <div class="categories-panel-description">
                                                        <?php echo wp_kses_post($twp_cat_description); ?>
                                                    </div>
                                                    <div class="theme-block-link">
                                                        <a href="<?php echo esc_url($twp_cat_link); ?>">Learn More</a>
                                                    </div>
                                                <?php } ?>
                                               

                                            </div>
                                        </div>
                                    </div>
                            <?php  } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php }
    }

endif;


if( !function_exists( 'storyyellers_cta_section' ) ) :

    function storyyellers_cta_section(){
        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_cta_section = get_theme_mod( 'ed_cta_section', $storyyellers_default['ed_cta_section'] );
        $ed_cta_post_excerpt = get_theme_mod( 'ed_cta_post_excerpt', $storyyellers_default['ed_cta_post_excerpt'] );
        if ($ed_cta_section) {
        $storyyellers_cta_page = esc_attr(get_theme_mod('select_page_for_cta'));
        if (!empty($storyyellers_cta_page)) {
            $storyyellers_cta_page_args = array(
                'post_type' => 'page',
                'page_id' => $storyyellers_cta_page,
            );
        }
        $homepage_cta_button_text = get_theme_mod( 'homepage_cta_button_text',$storyyellers_default['homepage_cta_button_text'] );
        $header_banner_button_link = get_theme_mod( 'header_banner_button_link',$storyyellers_default['header_banner_button_link'] );
        $cta_link_tab = get_theme_mod( 'cta_link_tab',$storyyellers_default['cta_link_tab'] );
        $ed_cta_image_overlay = get_theme_mod( 'ed_cta_image_overlay',$storyyellers_default['ed_cta_image_overlay'] );
        if (!empty($storyyellers_cta_page_args)) {
            $storyyellers_cta_page_query = new WP_Query($storyyellers_cta_page_args);
            while ($storyyellers_cta_page_query->have_posts()): $storyyellers_cta_page_query->the_post();
                $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full');
                $url = $thumb['0'];
                ?>
                <div class="theme-block theme-block-cta">
                    <div class="wrapper">
                        <div class="theme-cta-panel <?php if ($url){ echo 'data-bg';} ?>" data-background="<?php echo esc_url($url); ?>">
                            <?php if($ed_cta_image_overlay){ ?>
                                <div class="data-bg-overlay"></div>
                            <?php } ?>
                            <div class="wrapper-inner flex-align-center">
                                <div class="column column-8 column-sm-12">
                                    <div class="cta-panel">
                                         <div class="cta-panel-header">
                                             <h2 class="theme-block-title theme-block-title-large"><?php the_title();?></h2>
                                         </div>
                                         <?php if ($ed_cta_post_excerpt) { ?>
                                            <div class="cta-panel-content">
                                                <?php the_excerpt();?>
                                            </div>
                                         <?php } ?>
                                    </div>
                                </div>
                                 <div class="column column-4 column-sm-12">

                                    <?php
                                    if ($homepage_cta_button_text) { ?>
                                        <div class="theme-block-link">
                                            <a href="<?php echo esc_url($header_banner_button_link); ?>" class="theme-button" <?php if($cta_link_tab){ ?>target="_blank"<?php } ?>>
                                                <span><?php echo esc_html($homepage_cta_button_text); ?></span>
                                                <span><?php storyyellers_the_theme_svg('arrow-right'); ?></span>
                                            </a>
                                        </div>
                                    <?php } ?>
                                 </div>
                            </div>
                        </div>
                    </div>

                </div>
            <?php endwhile;
            wp_reset_postdata();
        }
        }
    }

endif;


if( !function_exists( 'storyyellers_testimonial_section' ) ) :

    function storyyellers_testimonial_section(){
        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_testimonial_section = get_theme_mod( 'ed_testimonial_section', $storyyellers_default['ed_testimonial_section'] );
        $testimonial_bg_image = get_theme_mod( 'testimonial_bg_image');
        if ($ed_testimonial_section) {
            $number_of_testimonial = absint(get_theme_mod('number_of_testimonial'));

                    $storyyellers_testimonial_page = array();
                    for ($i = 1; $i <= $number_of_testimonial; $i++) {
                        $storyyellers_testimonial_page_list = get_theme_mod('select_page_for_testimonial_' . $i);
                        if (!empty($storyyellers_testimonial_page_list)) {
                            $storyyellers_testimonial_page[] = absint($storyyellers_testimonial_page_list);
                        }
                    }
                    // Bail if no valid pages are selected.
                    if (empty($storyyellers_testimonial_page)) {
                        return;
                    }
                    /*page query*/
                    $storyyellers_testimonial_args = array(
                        'posts_per_page' => esc_attr($number_of_testimonial),
                        'orderby' => 'post__in',
                        'post_type' => 'page',
                        'post__in' => $storyyellers_testimonial_page,
                    );
                $storyyellers_testimonial_query = new WP_Query($storyyellers_testimonial_args); ?>
                <div class="theme-block theme-block-testimonials <?php if ($testimonial_bg_image){echo 'data-bg';} ?>" <?php if ($testimonial_bg_image){ ?>data-background="<?php echo esc_url($testimonial_bg_image); ?>"<?php } ?>>
                    <div class="wrapper wrapper-small">
                        <h2 class="theme-block-title theme-block-title-large secondary-font text-center">
                            <?php echo wp_kses_post(get_theme_mod('testimonial_section_title')); ?>
                        </h2>
                        <div class="testimonial-slider">
                            <?php
                            if ($storyyellers_testimonial_query->have_posts()) :
                                while ($storyyellers_testimonial_query->have_posts()) : $storyyellers_testimonial_query->the_post();
                                    if (has_post_thumbnail()) {
                                        $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'medium');
                                        $url = $thumb['0'];
                                    } else {
                                        $url = '';
                                    }
                                    ?>

                                    <div class="testimonial-slides">
                                        <?php if (!empty($url)) { ?>
                                            <div class="testimonial-image">
                                                <img src="<?php echo esc_url($url); ?>" title="<?php the_title_attribute(); ?>" alt="<?php the_title_attribute(); ?>">
                                            </div>
                                        <?php } ?>
                                        <div class="testimonial-content text-center">
                                            <h3 class="testimonial-title ">
                                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                            </h3>
                                            <div class="testimonial-caption">
                                                <?php the_excerpt(); ?>
                                            </div>

                                        </div>
                                    </div>
                                    <?php
                                endwhile;
                                wp_reset_postdata();
                            endif; ?>
                        </div>
                    </div>
                </div>
        <?php }
    }

endif;

if( !function_exists( 'storyyellers_fonts_url' ) ) :

    //Google Fonts URL
    function storyyellers_fonts_url(){

        $font_families = array(
            'Inter:wght@100;200;300;400;500;600;700',
            'Bodoni+Moda:ital,wght@0,400;0,500;1,400;1,500',
            'Heebo:wght@100;200;300;400;500',
            'Mr+Dafoe'
        );

        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $font_families ),
            'display' => 'swap',
        ), 'https://fonts.googleapis.com/css2' );

        return esc_url_raw($fonts_url);

    }

endif;

if( !function_exists('storyyellers_read_more_render') ):

    function storyyellers_read_more_render(){ 
        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$storyyellers_default['ed_post_excerpt'] );
        if( $ed_post_excerpt ){ ?>

        <div class="mp-read-more">
            <a class="mp-read-more-src" href="<?php the_permalink(); ?>"><?php esc_html_e('Read More','storyyellers'); ?></a>
        </div>

    <?php }
    }

endif;

if( !function_exists( 'storyyellers_social_menu_icon' ) ) :

    function storyyellers_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( 'storyyellers-social-menu' === $args->theme_location ) {

            $svg = Storyyellers_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = storyyellers_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'storyyellers_social_menu_icon', 10, 4 );

if( !function_exists( 'storyyellers_add_sub_toggles_to_main_menu' ) ) :

    function storyyellers_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

        // Add sub menu toggles to the Expanded Menu with toggles.
        if( isset( $args->show_toggles ) && $args->show_toggles ){

            // Wrap the menu item link contents in a div, used for positioning.
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';

            // Add a toggle to items with children.
            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle.
                $args->after .= '<button class="toggle submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'storyyellers' ) . '</span>' . storyyellers_the_theme_svg( 'chevron-down',$return = true ) . '</span></button>';

            }

            // Close the wrapper.
            $args->after .= '</div><!-- .submenu-wrapper -->';

            // Add sub menu icons to the primary menu without toggles.
        }elseif( 'storyyellers-primary-menu' === $args->theme_location ){

            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $args->after = '<span class="icon">'.storyyellers_the_theme_svg('chevron-down',true).'</span>';

            }else{

                $args->after = '';

            }
        }

        return $args;

    }

endif;

add_filter( 'nav_menu_item_args', 'storyyellers_add_sub_toggles_to_main_menu', 10, 3 );

if( !function_exists( 'storyyellers_sanitize_sidebar_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_sidebar_option_meta( $input ){

        $metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }
    }

endif;

if( !function_exists( 'storyyellers_page_lists' ) ) :

    // Page List.
    function storyyellers_page_lists(){

        $page_lists = array();
        $page_lists[''] = esc_html__( '-- Select Page --','storyyellers' );
        $pages = get_pages();
        foreach( $pages as $page ){

            $page_lists[$page->ID] = $page->post_title;

        }
        return $page_lists;
    }

endif;

if( !function_exists( 'storyyellers_sanitize_post_layout_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_post_layout_option_meta( $input ){

        $metabox_options = array( 'global-layout','layout-1','layout-2' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

if( !function_exists( 'storyyellers_sanitize_header_overlay_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_header_overlay_option_meta( $input ){

        $metabox_options = array( 'global-layout','enable-overlay' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

/**
 * StoryYellers SVG Icon helper functions
 *
 * @package StoryYellers
 * @since 1.0.0
 */
if ( ! function_exists( 'storyyellers_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Storyyellers_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function storyyellers_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return storyyellers_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in storyyellers_get_theme_svg();.

        }else{

            echo storyyellers_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in storyyellers_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'storyyellers_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function storyyellers_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Storyyellers_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;


if( !function_exists( 'storyyellers_post_category_list' ) ) :

    // Post Category List.
    function storyyellers_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','storyyellers' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('storyyellers_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function storyyellers_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('storyyellers_disable_post_views') ):

    /** Disable Post Views **/
    function storyyellers_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('storyyellers_disable_post_read_time') ):

    /** Disable Read Time **/
    function storyyellers_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('storyyellers_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function storyyellers_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('storyyellers_disable_post_author_box') ):

    /** Disable Author Box **/
    function storyyellers_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed', function ( ) {
            return false;
        });

    }

endif;


add_filter('booster_extension_filter_ss_ed', function ( ) {
    return false;
});

if( !function_exists('storyyellers_disable_post_reaction') ):

    /** Disable Reaction **/
    function storyyellers_disable_post_reaction() {

        add_filter('booster_extension_filter_reaction_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('storyyellers_post_floating_nav') ):

    function storyyellers_post_floating_nav(){

        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_floating_next_previous_nav = get_theme_mod( 'ed_floating_next_previous_nav',$storyyellers_default['ed_floating_next_previous_nav'] );

        if( 'post' === get_post_type() && $ed_floating_next_previous_nav ){

            $next_post = get_next_post();
            $prev_post = get_previous_post();

            if( isset( $prev_post->ID ) ){

                $prev_link = get_permalink( $prev_post->ID );?>

                <div class="floating-post-navigation floating-navigation-prev">
                    <?php if( get_the_post_thumbnail( $prev_post->ID,'medium' ) ){ ?>
                            <?php echo wp_kses_post( get_the_post_thumbnail( $prev_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $prev_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Previous post', 'storyyellers'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php }

            if( isset( $next_post->ID ) ){

                $next_link = get_permalink( $next_post->ID );?>

                <div class="floating-post-navigation floating-navigation-next">
                    <?php if( get_the_post_thumbnail( $next_post->ID,'medium' ) ){ ?>
                        <?php echo wp_kses_post( get_the_post_thumbnail( $next_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $next_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Next post', 'storyyellers'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php
            }

        }

    }

endif;

add_action( 'storyyellers_navigation_action','storyyellers_post_floating_nav',10 );

if( !function_exists('storyyellers_single_post_navigation') ):

    function storyyellers_single_post_navigation(){

        $storyyellers_default = storyyellers_get_default_theme_options();
        $twp_navigation_type = esc_attr( get_post_meta( get_the_ID(), 'twp_disable_ajax_load_next_post', true ) );
        global $post;
        if( $twp_navigation_type == '' || $twp_navigation_type == 'global-layout' ){
            $twp_navigation_type = get_theme_mod('twp_navigation_type', $storyyellers_default['twp_navigation_type']);
        }


        if( $twp_navigation_type != 'no-navigation' && 'post' === get_post_type() ){

            if( $twp_navigation_type == 'norma-navigation' ){ ?>

                <div class="theme-block navigation-wrapper">
                    <?php
                    // Previous/next post navigation.
                    the_post_navigation(array(
                        'prev_text' => '<span class="arrow" aria-hidden="true">' . storyyellers_the_theme_svg('arrow-left',$return = true ) . '</span><span class="screen-reader-text">' . __('Previous post:', 'storyyellers') . '</span><h4 class="entry-title entry-title-medium">%title</h4>',
                        'next_text' => '<span class="arrow" aria-hidden="true">' . storyyellers_the_theme_svg('arrow-right',$return = true ) . '</span><span class="screen-reader-text">' . __('Next post:', 'storyyellers') . '</span><h4 class="entry-title entry-title-medium">%title</h4>',
                    )); ?>
                </div>
                <?php

            }else{

                $next_post = get_next_post();
                if( isset( $next_post->ID ) ){

                    $next_post_id = $next_post->ID;
                    echo '<div loop-count="1" next-post="' . absint( $next_post_id ) . '" class="twp-single-infinity"></div>';

                }
            }

        }

    }

endif;

add_action( 'storyyellers_navigation_action','storyyellers_single_post_navigation',30 );

if ( ! function_exists( 'storyyellers_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function storyyellers_header_toggle_search() {

        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_header_search = get_theme_mod( 'ed_header_search', $storyyellers_default['ed_header_search'] );
        $ed_header_search_top_category = get_theme_mod( 'ed_header_search_top_category', $storyyellers_default['ed_header_search_top_category'] );
        $ed_header_search_recent_posts = absint( get_theme_mod( 'ed_header_search_recent_posts',$storyyellers_default['ed_header_search_recent_posts'] ) );
        
        if( $ed_header_search ){ ?>

            <div class="header-searchbar">
                <div class="header-searchbar-inner">
                    <div class="wrapper">

                        <div class="header-searchbar-area">

                            <a href="javascript:void(0)" class="skip-link-search-start"></a>
                            
                            <?php get_search_form(); ?>

                        </div>

                        <?php if( $ed_header_search_recent_posts || $ed_header_search_top_category ){ ?>

                            <div class="search-content-area">
                                  
                                <?php if( $ed_header_search_recent_posts ){ ?>

                                    <div class="search-recent-posts">
                                        <?php storyyellers_recent_posts_search(); ?>
                                    </div>

                                <?php } ?>

                                <?php if( $ed_header_search_top_category ){ ?>

                                    <div class="search-popular-categories">
                                        <?php storyyellers_header_search_top_cat_content(); ?>
                                    </div>

                                <?php } ?>

                            </div>

                        <?php } ?>

                        <button type="button" id="search-closer" class="exit-search">
                            <?php storyyellers_the_theme_svg('cross'); ?>
                        </button>

                        <a href="javascript:void(0)" class="skip-link-search-end"></a>

                    </div>
                </div>
            </div>

        <?php
        }

    }

endif;

if( !function_exists('storyyellers_recent_posts_search') ):

    // Single Posts Related Posts.
    function storyyellers_recent_posts_search(){

        $storyyellers_default = storyyellers_get_default_theme_options();
        $related_posts_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 5,'post__not_in' => get_option("sticky_posts") ) );

        if( $related_posts_query->have_posts() ): ?>

            <div class="related-search-posts">

                <div class="theme-block-heading">
                    <?php
                    $recent_post_title_search = esc_html( get_theme_mod( 'recent_post_title_search',$storyyellers_default['recent_post_title_search'] ) );

                    if( $recent_post_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $recent_post_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <div class="theme-list-group recent-list-group">

                    <?php
                    while( $related_posts_query->have_posts() ):
                        $related_posts_query->the_post(); ?>

                        <div class="search-recent-article-list">
                            <header class="entry-header">
                                <h3 class="entry-title">
                                    <a href="<?php the_permalink(); ?>" rel="bookmark">
                                        <?php the_title(); ?>
                                    </a>
                                </h3>
                            </header>
                        </div>

                    <?php 
                    endwhile; ?>

                </div>

            </div>

            <?php
            wp_reset_postdata();

        endif;

    }

endif;

if( !function_exists('storyyellers_header_search_top_cat_content') ):

    function storyyellers_header_search_top_cat_content(){

        $top_category = 3;

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $slug_counts = array();

        foreach( $post_cat_lists as $post_cat_list ){

            if( $post_cat_list->count >= 1 ){

                $slug_counts[] = array( 
                    'count'         => $post_cat_list->count,
                    'slug'          => $post_cat_list->slug,
                    'name'          => $post_cat_list->name,
                    'cat_ID'        => $post_cat_list->cat_ID,
                    'description'   => $post_cat_list->category_description, 
                );

            }

        }

        if( $slug_counts ){?>

            <div class="popular-search-categories">
                
                <div class="theme-block-heading">
                    <?php
                    $storyyellers_default = storyyellers_get_default_theme_options();
                    $top_category_title_search = esc_html( get_theme_mod( 'top_category_title_search',$storyyellers_default['top_category_title_search'] ) );

                    if( $top_category_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $top_category_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <?php
                arsort( $slug_counts ); ?>

                <div class="theme-list-group categories-list-group">
                    <div class="wrapper-inner">

                        <?php
                        $i = 1;
                        foreach( $slug_counts as $key => $slug_count ){

                            if( $i > $top_category){ break; }
                            
                            $cat_link           = get_category_link( $slug_count['cat_ID'] );
                            $cat_name           = $slug_count['name'];
                            $twp_term_image = get_term_meta( $slug_count['cat_ID'], 'twp-term-featured-image', true ); ?>

                            <div class="column column-4 column-sm-12">
                                <article id="post-<?php the_ID(); ?>" <?php post_class('theme-grid-article'); ?>>
                                        <div class="entry-wrapper">
                                            <?php if ($twp_term_image) { ?>
                                                <div class="entry-thumbnail">
                                                    <a href="<?php echo esc_url($cat_link); ?>" class="data-bg data-bg-medium" data-background="<?php echo esc_url($twp_term_image); ?>"></a>
                                                </div>
                                            <?php } ?>

                                            <div class="post-content">
                                                <header class="entry-header">
                                                    <h3 class="entry-title">
                                                        <a href="<?php echo esc_url($cat_link); ?>">
                                                            <?php echo esc_html($cat_name); ?>
                                                        </a>
                                                    </h3>
                                                </header>
                                            </div>
                                        </div>
                                </article>
                            </div>

                            <?php
                            $i++;

                        } ?>

                    </div>
                </div>

            </div>
        <?php
        }

    }

endif;

add_action( 'storyyellers_before_footer_content_action','storyyellers_header_toggle_search',10 );

if( !function_exists('storyyellers_content_offcanvas') ):

    // Offcanvas Contents
    function storyyellers_content_offcanvas(){ ?>

        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">

                <div class="close-offcanvas-menu">
                    <div class="offcanvas-close">

                        <a href="javascript:void(0)" class="skip-link-menu-start"></a>

                        <button type="button" class="button-offcanvas-close">
                            <?php storyyellers_the_theme_svg('close'); ?>
                        </button>

                    </div>
                </div>

                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e('Horizontal', 'storyyellers'); ?>" role="navigation">
                        <ul class="primary-menu">

                            <?php
                            if( has_nav_menu('storyyellers-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'storyyellers-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{
                                
                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'show_sub_menu_icons' => false,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new Storyyellers_Walker_Page(),
                                    )
                                );
                            } ?>

                        </ul>
                    </nav><!-- .primary-menu-wrapper -->
                </div>

                <?php if( has_nav_menu('storyyellers-social-menu') ){ ?>

                    <div id="social-nav-offcanvas" class="offcanvas-item theme-social-navigation">

                        <?php
                        wp_nav_menu(array(
                            'theme_location' => 'storyyellers-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>

                    </div>

                <?php } ?>

                <a href="javascript:void(0)" class="skip-link-menu-end"></a>

            </div>
        </div>

    <?php
    }

endif;

add_action( 'storyyellers_before_footer_content_action','storyyellers_content_offcanvas',30 );

if( !function_exists('storyyellers_footer_content_widget') ):

    function storyyellers_footer_content_widget(){

        $storyyellers_default = storyyellers_get_default_theme_options();
        if( is_active_sidebar('storyyellers-footer-widget-0') || 
            is_active_sidebar('storyyellers-footer-widget-1') || 
            is_active_sidebar('storyyellers-footer-widget-2') ):

            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 3 && is_active_sidebar('storyyellers-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('storyyellers-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('storyyellers-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 3);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } else {
                $footer_sidebar_class = 4;
            }
            $footer_column_layout = absint(get_theme_mod('footer_column_layout', $storyyellers_default['footer_column_layout'])); ?>

            <div class="wrapper">
                <div class="footer-widgetarea">
                    <div class="wrapper-inner">

                        <?php if (is_active_sidebar('storyyellers-footer-widget-0')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('storyyellers-footer-widget-0'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('storyyellers-footer-widget-1')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('storyyellers-footer-widget-1'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('storyyellers-footer-widget-2')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('storyyellers-footer-widget-2'); ?>
                            </div>
                        <?php endif; ?>

                    </div>
                </div>
            </div>

        <?php
        endif;

    }

endif;

add_action( 'storyyellers_footer_content_action','storyyellers_footer_content_widget',10 );


if( !function_exists('storyyellers_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function storyyellers_footer_content_info(){

        $storyyellers_default = storyyellers_get_default_theme_options(); ?>
        <div class="wrapper">
            <div class="site-info">
                <div class="wrapper-inner">

                    <div class="column column-8">
                        <div class="footer-credits">

                            <div class="footer-copyright">

                                <?php
                                $ed_footer_copyright = wp_kses_post( get_theme_mod( 'ed_footer_copyright', $storyyellers_default['ed_footer_copyright'] ) );
                                $footer_copyright_text = wp_kses_post( get_theme_mod( 'footer_copyright_text', $storyyellers_default['footer_copyright_text'] ) );

                                echo esc_html__('Copyright ', 'storyyellers') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html( get_bloginfo( 'name', 'display' ) ) . '. </span></a> ' . esc_html( $footer_copyright_text );

                                if( $ed_footer_copyright ){

                                    echo '<br>';
                                    echo esc_html__('Theme: ', 'storyyellers') . 'StoryYellers ' . esc_html__('By ', 'storyyellers') . '<a href="' . esc_url('https://www.themeinwp.com/theme/storyyellers') . '"  title="' . esc_attr__('Themeinwp', 'storyyellers') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'storyyellers') . '</span></a>';

                                    echo esc_html__('Powered by ', 'storyyellers') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'storyyellers') . '" target="_blank"><span>' . esc_html__('WordPress.', 'storyyellers') . '</span></a>';

                                } ?>

                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>

    <?php
    }

endif;

add_action( 'storyyellers_footer_content_action','storyyellers_footer_content_info',20 );


if( !function_exists('storyyellers_footer_go_to_top') ):

    // Scroll to Top render content
    function storyyellers_footer_go_to_top(){ ?>

        <button type="button" class="scroll-up">
<span class="scroll-ip-icon">
            <?php storyyellers_the_theme_svg('arrow-up'); ?>
</span>
        </button>
    
    <?php
    }

endif;

add_action( 'storyyellers_footer_content_action','storyyellers_footer_go_to_top',30 );

if( !function_exists('storyyellers_color_schema_color') ):

    function storyyellers_color_schema_color( $current_color ){

        $storyyellers_default = storyyellers_get_default_theme_options();

        $colors_schema = array(

            'default' => array(

                'background_color' => '#ffffff',
                'storyyellers_primary_color' => $storyyellers_default['storyyellers_primary_color'],
                'storyyellers_secondary_color' => $storyyellers_default['storyyellers_secondary_color'],
                'storyyellers_general_color' => $storyyellers_default['storyyellers_general_color'],

            ),

            'dark' => array(

                'background_color' => '#222222',
                'storyyellers_primary_color' => $storyyellers_default['storyyellers_primary_color_dark'],
                'storyyellers_secondary_color' => $storyyellers_default['storyyellers_secondary_color_dark'],
                'storyyellers_general_color' => $storyyellers_default['storyyellers_general_color_dark'],

            ),

            'fancy' => array(

                'background_color' => '#faf7f2',
                'storyyellers_primary_color' => $storyyellers_default['storyyellers_primary_color_fancy'],
                'storyyellers_secondary_color' => $storyyellers_default['storyyellers_secondary_color_fancy'],
                'storyyellers_general_color' => $storyyellers_default['storyyellers_general_color_fancy'],

            ),

        );

        if( isset( $colors_schema[$current_color] ) ){
            
            return $colors_schema[$current_color];

        }

        return;

    }

endif;



if ( ! function_exists( 'storyyellers_color_schema_color_action' ) ) :
    
    function storyyellers_color_schema_color_action() {

        if( isset( $_POST['currentColor'] ) && sanitize_text_field( wp_unslash( $_POST['currentColor'] ) ) ){
         
            $current_color = sanitize_text_field( wp_unslash( $_POST['currentColor'] ) );

            $color_schemes = storyyellers_color_schema_color( $current_color );

            if ( $color_schemes ) {
                echo json_encode( $color_schemes );
            }
        }
    
        wp_die();

    }

endif;

add_action( 'wp_ajax_nopriv_storyyellers_color_schema_color', 'storyyellers_color_schema_color_action' );
add_action( 'wp_ajax_storyyellers_color_schema_color', 'storyyellers_color_schema_color_action' );

if( ! function_exists( 'storyyellers_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function storyyellers_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','storyyellers_after_content_pagination');

}

if( !function_exists('storyyellers_after_content_pagination') ):

    function storyyellers_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'storyyellers' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( !function_exists('storyyellers_excerpt_content') ):

    function storyyellers_excerpt_content(){ 

        $storyyellers_default = storyyellers_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$storyyellers_default['ed_post_excerpt'] );

        if( $ed_post_excerpt ){ ?>
                    
            <div class="entry-content">

                <?php
                if( has_excerpt() ){

                    the_excerpt();

                }else{

                    echo esc_html( wp_trim_words( get_the_content(), 25, '...' ) );

                } ?>

            </div>

        <?php }
    }

endif;


if( !function_exists('storyyellers_footer_related_posts') ):

    // Footer Posts Related Posts.
    function storyyellers_footer_related_posts(){
        
        $storyyellers_default = storyyellers_get_default_theme_options();
        $enable_footer_related_post = esc_html(get_theme_mod('enable_footer_related_post', $storyyellers_default['enable_footer_related_post']));
        if ($enable_footer_related_post) {
            $footer_related_posts_query = new WP_Query(
                    array(
                    'post_type' => 'post',
                    'posts_per_page' => absint( get_theme_mod( 'number_of_footer_related_post')),
                    'cat' => esc_attr(get_theme_mod( 'select_category_for_related_post')),
                    )
            );

            if( $footer_related_posts_query->have_posts() ): ?>
                <div class="theme-block theme-block-bg theme-block-recommended">
                    <div class="wrapper-fluid">
                        <div class="wrapper-inner">
                            <div class="column column-3 column-sm-12">
                                <div class="theme-block-heading">
                                <?php
                                $footer_recent_post_title = esc_html(get_theme_mod('footer_related_post_title', $storyyellers_default['footer_related_post_title']));
                                $footer_related_post_sub_title = esc_html(get_theme_mod('footer_related_post_sub_title', $storyyellers_default['footer_related_post_sub_title']));

                                if ($footer_recent_post_title) { ?>

                                    <h2 class="theme-block-title theme-block-title-large">

                                        <?php echo esc_html($footer_recent_post_title); ?>

                                    </h2>

                                    <?php } ?>
                                    <?php if ($footer_related_post_sub_title) {
                                       echo esc_html($footer_related_post_sub_title);
                                    }?>
                                </div>
                            </div>
                            <div class="column column-9 column-sm-12">
                                <div class="theme-recommended-slider slick-space">
                                    <?php
                                    while ($footer_related_posts_query->have_posts()):
                                        $footer_related_posts_query->the_post(); ?>
                                        <article <?php post_class('recommended-slides'); ?>>
                                            <div class="entry-wrapper">

                                                <?php if( has_post_thumbnail() ){
                                                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'medium_large' );
                                                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                                    <div class="entry-thumbnail">
                                                        <a href="<?php the_permalink(); ?>">
                                                            <span class="data-bg data-bg-big" data-background="<?php echo esc_url( $featured_image ); ?>"></span>
                                                        </a>
                                                    </div>

                                                <?php }?>

                                                <div class="post-content">
                                                    <div class="entry-meta theme-meta-categories">
                                                        <?php storyyellers_entry_footer($cats = true, $tags = false, $edits = false); ?>
                                                    </div>

                                                    <header class="entry-header">
                                                        <h3 class="entry-title entry-title-medium alt-font">
                                                            <a href="<?php the_permalink(); ?>">
                                                                <?php the_title(); ?>
                                                            </a>
                                                        </h3>
                                                    </header>

                                                    <div class="entry-meta">

                                                        <?php
                                                        storyyellers_posted_by();
                                                        storyyellers_posted_on();
                                                        ?>

                                                    </div>

                                                </div>
                                            </div>
                                        </article>
                                    <?php
                                    endwhile;
                                    wp_reset_postdata();
                                    ?>
                                </div>
                                <?php

                                $footer_recent_post_button_text = esc_html(get_theme_mod('footer_related_post_button', $storyyellers_default['footer_related_post_button']));
                                $footer_recent_post_button_url = esc_html(get_theme_mod('footer_related_post_button_url', $storyyellers_default['footer_related_post_button_url']));

                                if ($footer_recent_post_button_text) { ?>
                                    <div class="theme-block-link">
                                        <a href="<?php echo esc_url($footer_recent_post_button_url); ?>" class="theme-button-hashed">
                                            <?php echo esc_html($footer_recent_post_button_text); ?>
                                        </a>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endif;
        }

    }

endif;