<?php
/**
 * Default Values.
 *
 * @package StoryYellers
 */

if ( ! function_exists( 'storyyellers_get_default_theme_options' ) ) :

    /**
     * Get default theme options
     *
     * @since 1.0.0
     *
     * @return array Default theme options.
     */
    function storyyellers_get_default_theme_options() {

        $storyyellers_defaults = array();
        $storyyellers_category_colors = array(
            array(
                'category' => '1',
                'category_color' => '#0027ff',
            ),
        );

        $storyyellers_category_colors = json_encode($storyyellers_category_colors);
        $storyyellers_defaults['storyyellers_category_colors'] = $storyyellers_category_colors;

        // header banner
        $storyyellers_defaults['ed_header_banner']                       = 0;
        $storyyellers_defaults['ed_transparent_menu']                    = 0;
        $storyyellers_defaults['ed_header_banner_overlay']               = 0;
        $storyyellers_defaults['header_banner_title']                    = esc_html__( 'Hello World', 'storyyellers' );
        $storyyellers_defaults['header_banner_sub_title']                = esc_html__( 'This is sub-title', 'storyyellers' );
        $storyyellers_defaults['header_banner_description']              = '';
        $storyyellers_defaults['header_banner_button_label']             = esc_html__( 'Get Started', 'storyyellers' );
        $storyyellers_defaults['header_banner_button_link']              = '';
        $storyyellers_defaults['ed_open_link_new_tab']                   = 1;
        $storyyellers_defaults['storyyellers_header_text_color']         = '#000000';

        // homepage cta
        $storyyellers_defaults['ed_cta_section']                        = 0;
        $storyyellers_defaults['ed_cta_image_overlay']                  = 0;
        $storyyellers_defaults['ed_cta_post_excerpt']                  = 0;
        $storyyellers_defaults['cta_link_tab']                          = 0;
        $storyyellers_defaults['homepage_cta_button_text']              =  esc_html__( 'View More', 'storyyellers' );
        $storyyellers_defaults['homepage_cta_button_text_url']          = '';
        $storyyellers_defaults['homepage_cta_text_color']         = '#000000';


        $storyyellers_defaults['ed_category_image_overlay']             = 0;
        $storyyellers_defaults['ed_category_description']               = 0;

        // homepage category
        $storyyellers_defaults['ed_category_section']                   = 0;
        $storyyellers_defaults['category_title_text_color']             = '#000000';

        
        // homepage testimonial
        $storyyellers_defaults['ed_testimonial_section']                   = 0;
        $storyyellers_defaults['number_of_testimonial']                    = 3;
        $storyyellers_defaults['testimonial_section_title']                = esc_html__( 'Customer Testimonials', 'storyyellers' );

        // Options.
        $storyyellers_defaults['storyyellers_pagination_layout']      = 'numeric';
        $storyyellers_defaults['footer_column_layout']                       = 3;
        $storyyellers_defaults['footer_copyright_text']                      = esc_html__( 'All rights reserved.', 'storyyellers' );
        $storyyellers_defaults['ed_header_search']                           = 1;
        $storyyellers_defaults['ed_image_content_inverse']                   = 0;
        $storyyellers_defaults['ed_related_post']                            = 1;
        $storyyellers_defaults['related_post_title']                         = esc_html__('Related Post','storyyellers');
        $storyyellers_defaults['twp_navigation_type']                        = 'norma-navigation';
        $storyyellers_defaults['ed_post_author']                             = 1;
        $storyyellers_defaults['ed_post_date']                               = 1;
        $storyyellers_defaults['ed_post_category']                           = 1;
        $storyyellers_defaults['ed_post_tags']                               = 1;
        $storyyellers_defaults['ed_floating_next_previous_nav']               = 1;
        $storyyellers_defaults['ed_footer_copyright']                        = 1;

        // Default Color
        $storyyellers_defaults['background_color']                      = 'ffffff';
        $storyyellers_defaults['storyyellers_primary_color']            = '#000000';
        $storyyellers_defaults['storyyellers_secondary_color']          = '#0027ff';
        $storyyellers_defaults['storyyellers_general_color']            = '#000000';

        // Simple Color
        $storyyellers_defaults['storyyellers_primary_color_dark']          = '#007CED';
        $storyyellers_defaults['storyyellers_secondary_color_dark']        = '#fb7268';
        $storyyellers_defaults['storyyellers_general_color_dark']        = '#ffffff';

        // Fancy Color
        $storyyellers_defaults['storyyellers_primary_color_fancy']          = '#017eff';
        $storyyellers_defaults['storyyellers_secondary_color_fancy']        = '#fc9285';
        $storyyellers_defaults['storyyellers_general_color_fancy']          = '#455d58';

        $storyyellers_defaults['ed_open_link_new_tab']                      = 0;
        $storyyellers_defaults['storyyellers_color_schema']                 = 'default';
        $storyyellers_defaults['ed_desktop_menu']                           = 1;
        $storyyellers_defaults['ed_post_excerpt']                           = 0;
        $storyyellers_defaults['recent_post_title_search']                  = esc_html__('Recent Post','storyyellers');
        $storyyellers_defaults['top_category_title_search']                 = esc_html__('Top Category','storyyellers');
        $storyyellers_defaults['ed_header_search_recent_posts']             = 1;
        $storyyellers_defaults['ed_header_search_top_category']             = 1;
        
        // footer related post
        $storyyellers_defaults['enable_footer_related_post']             = 0;
        $storyyellers_defaults['footer_related_post_title']              = esc_html__('You May Like','storyyellers');
        $storyyellers_defaults['footer_related_post_sub_title']          = esc_html__('This is sub-title','storyyellers');
        $storyyellers_defaults['number_of_footer_related_post']          = 8;
        $storyyellers_defaults['select_category_for_related_post']       = 0;
        $storyyellers_defaults['footer_related_post_button']             = esc_html__('View Blog','storyyellers');
        $storyyellers_defaults['footer_related_post_button_url']         = '';

        $storyyellers_defaults['home_section_arrange_vals']                             =  'homepage_category_Section,static_front_page,homepage_testimonial_Section,homepage_cta_Section,homepage_footer_recomend_section';

        // Pass through filter.
        $storyyellers_defaults = apply_filters( 'storyyellers_filter_default_theme_options', $storyyellers_defaults );

        return $storyyellers_defaults;

    }

endif;
