<?php
/**
* Homepage Settings.
*
* @package StoryYellers
*/

$storyyellers_default = storyyellers_get_default_theme_options();

// Homepage Category section settings.
$wp_customize->add_section( 'homepage_category_Section',
    array(
    'title'      => esc_html__( 'Category Section Settings', 'storyyellers' ),
    'capability' => 'edit_theme_options',
    'panel'      => 'homepage_option_panel',
    )
);

$wp_customize->add_setting('ed_category_section',
    array(
        'default' => $storyyellers_default['ed_category_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_category_section',
    array(
        'label' => esc_html__('Enable Category Section', 'storyyellers'),
        'section' => 'homepage_category_Section',
        'type' => 'checkbox',
    )
);


$wp_customize->add_setting('ed_category_image_overlay',
    array(
        'default' => $storyyellers_default['ed_category_image_overlay'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_category_image_overlay',
    array(
        'label' => esc_html__('Enable Category Image Overlay', 'storyyellers'),
        'section' => 'homepage_category_Section',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting('ed_category_description',
    array(
        'default' => $storyyellers_default['ed_category_description'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_category_description',
    array(
        'label' => esc_html__('Enable Category Description', 'storyyellers'),
        'section' => 'homepage_category_Section',
        'type' => 'checkbox',
    )
);

for ( $storyyellers_j=1; $storyyellers_j <=  3 ; $storyyellers_j++ ) {
    $wp_customize->add_setting('select_category_for_cat_list_'. $storyyellers_j,
        array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'absint',
        )
    );
    $wp_customize->add_control(new Storyyellers_Dropdown_Taxonomies_Control($wp_customize, 'select_category_for_cat_list_'. $storyyellers_j,
        array(
            'label'           => esc_html__('Category To List', 'storyyellers') . ' - ' . $storyyellers_j ,
            'section'         => 'homepage_category_Section',
            'type'            => 'dropdown-taxonomies',
            'taxonomy'        => 'category',

        )));
}

$wp_customize->add_setting( 'category_title_text_color',
    array(
    'default'           => $storyyellers_default['category_title_text_color'],
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(new WP_Customize_Color_Control( $wp_customize, 'category_title_text_color', 
    array(
        'label'      => esc_html__( 'Category Title Text Color', 'storyyellers' ),
        'section'    => 'homepage_category_Section',
        'settings'   => 'category_title_text_color',
    ) ) 
);

// Homepage testimonail section settings.
$wp_customize->add_section( 'homepage_testimonial_Section',
	array(
	'title'      => esc_html__( 'Testimonial Section Settings', 'storyyellers' ),
	'capability' => 'edit_theme_options',
	'panel'      => 'homepage_option_panel',
	)
);

$wp_customize->add_setting('ed_testimonial_section',
    array(
        'default' => $storyyellers_default['ed_testimonial_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_testimonial_section',
    array(
        'label' => esc_html__('Enable Testimonial Section', 'storyyellers'),
        'section' => 'homepage_testimonial_Section',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting('testimonial_bg_image',
    array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_image',
    )
);
$wp_customize->add_control(
    new WP_Customize_Image_Control($wp_customize, 'testimonial_bg_image',
        array(
            'label'       => esc_html__('Upload Section Background Image ', 'storyyellers'),
            'section'     => 'homepage_testimonial_Section',
        )
    )
);

$wp_customize->add_setting('testimonial_section_title',
    array(
        'default'           => $storyyellers_default['testimonial_section_title'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('testimonial_section_title',
    array(
        'label'       => esc_html__('Section Title', 'storyyellers'),
        'section'     => 'homepage_testimonial_Section',
        'type'        => 'text',
    )
);

$wp_customize->add_setting( 'number_of_testimonial',
    array(
        'default'           => $storyyellers_default['number_of_testimonial'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_select',
    )
);
$wp_customize->add_control( 'number_of_testimonial',
    array(
        'label'    => esc_html__( 'Select no of slider', 'storyyellers' ),
        'description'     => esc_html__( 'Please refresh to get actual no of page field below', 'storyyellers' ),
        'section'  => 'homepage_testimonial_Section',
        'choices'               => array(
            '1' => esc_html__( '1', 'storyyellers' ),
            '2' => esc_html__( '2', 'storyyellers' ),
            '3' => esc_html__( '3', 'storyyellers' ),
            '4' => esc_html__( '4', 'storyyellers' ),
            '5' => esc_html__( '5', 'storyyellers' ),
            '6' => esc_html__( '6', 'storyyellers' ),
            ),
        'type'     => 'select',
    )
);

$testimonial_number = get_theme_mod( 'number_of_testimonial', $storyyellers_default['number_of_testimonial'] );
for ( $storyyellers_i=1; $storyyellers_i <=  $testimonial_number ; $storyyellers_i++ ) {
    $wp_customize->add_setting( 'select_page_for_testimonial_'. $storyyellers_i, array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_dropdown_pages',
    ) );

    $wp_customize->add_control( 'select_page_for_testimonial_'. $storyyellers_i, array(
        'input_attrs'       => array(
            'style'           => 'width: 50px;'
            ),
        'label'             => __( 'Select Testimonial Page', 'storyyellers' ) . ' - ' . $storyyellers_i ,
        'section'           => 'homepage_testimonial_Section',
        'type'              => 'dropdown-pages',
        'allow_addition' => true,
        )
    );
}


// Homepage CTA section settings.
$wp_customize->add_section( 'homepage_cta_Section',
    array(
    'title'      => esc_html__( 'CTA Section Settings', 'storyyellers' ),
    'capability' => 'edit_theme_options',
    'panel'      => 'homepage_option_panel',
    )
);

$wp_customize->add_setting('ed_cta_section',
    array(
        'default' => $storyyellers_default['ed_cta_section'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_cta_section',
    array(
        'label' => esc_html__('Enable CTA Section', 'storyyellers'),
        'section' => 'homepage_cta_Section',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting( 'select_page_for_cta', array(
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'storyyellers_sanitize_dropdown_pages',
) );

$wp_customize->add_control( 'select_page_for_cta', array(
    'label'             => __( 'Select Call To Action Page', 'storyyellers' ) ,
    'section'           => 'homepage_cta_Section',
    'type'              => 'dropdown-pages',
    'allow_addition' => true,
    )
);

$wp_customize->add_setting('ed_cta_image_overlay',
    array(
        'default' => $storyyellers_default['ed_cta_image_overlay'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_cta_image_overlay',
    array(
        'label' => esc_html__('Enable Section Overlay', 'storyyellers'),
        'section' => 'homepage_cta_Section',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting('ed_cta_post_excerpt',
    array(
        'default' => $storyyellers_default['ed_cta_post_excerpt'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_cta_post_excerpt',
    array(
        'label' => esc_html__('Enable CTA Excerpt Content', 'storyyellers'),
        'section' => 'homepage_cta_Section',
        'type' => 'checkbox',
    )
);

/*Button Text*/
$wp_customize->add_setting('homepage_cta_button_text',
    array(
        'default'           => $storyyellers_default['homepage_cta_button_text'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('homepage_cta_button_text',
    array(
        'label'       => esc_html__('Related Post Button Text', 'storyyellers'),
        'description' => esc_html__('Removing text will disable read more on the related post', 'storyyellers'),
        'section'     => 'homepage_cta_Section',
        'type'        => 'text',
    )
);

$wp_customize->add_setting('homepage_cta_button_text_url',
    array(
        'default'           => $storyyellers_default['homepage_cta_button_text_url'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control('homepage_cta_button_text_url',
    array(
        'label'       => esc_html__('Related Post Button URL', 'storyyellers'),
        'section'     => 'homepage_cta_Section',
        'type'        => 'text',
    )
);
$wp_customize->add_setting('cta_link_tab',
    array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);

$wp_customize->add_control('cta_link_tab',
    array(
        'label' => esc_html__('Open Link In New Tab', 'storyyellers'),
        'section' => 'homepage_cta_Section',
        'type' => 'checkbox',
    )
 );

$wp_customize->add_setting( 'homepage_cta_text_color',
    array(
    'default'           => $storyyellers_default['homepage_cta_text_color'],
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'sanitize_hex_color',
    )
);
$wp_customize->add_control(new WP_Customize_Color_Control( $wp_customize, 'homepage_cta_text_color', 
    array(
        'label'      => esc_html__( 'Section Text Color', 'storyyellers' ),
        'section'    => 'homepage_cta_Section',
        'settings'   => 'homepage_cta_text_color',
    ) ) 
);

$wp_customize->add_section( 'homepage_footer_recomend_section',
    array(
    'title'      => esc_html__( 'Footer  Section Settings', 'storyyellers' ),
    'capability' => 'edit_theme_options',
    'panel'      => 'homepage_option_panel',
    )
);
// Setting - enable_footer_related_post.
$wp_customize->add_setting('enable_footer_related_post',
    array(
        'default'           => $storyyellers_default['enable_footer_related_post'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_checkbox',
    )
);
$wp_customize->add_control('enable_footer_related_post',
    array(
        'label'    => esc_html__('Enable Footer Related Post', 'storyyellers'),
        'section'  => 'homepage_footer_recomend_section',
        'type'     => 'checkbox',
    )
);

$wp_customize->add_setting('footer_related_post_title',
    array(
        'default'           => $storyyellers_default['footer_related_post_title'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('footer_related_post_title',
    array(
        'label'       => esc_html__('Related Post Section Title', 'storyyellers'),
        'section'     => 'homepage_footer_recomend_section',
        'type'        => 'text',
    )
);

$wp_customize->add_setting('footer_related_post_sub_title',
    array(
        'default'           => $storyyellers_default['footer_related_post_sub_title'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('footer_related_post_sub_title',
    array(
        'label'       => esc_html__('Related Post Sub Title', 'storyyellers'),
        'section'     => 'homepage_footer_recomend_section',
        'type'        => 'text',
    )
);

$wp_customize->add_setting('number_of_footer_related_post',
    array(
        'default'           => $storyyellers_default['number_of_footer_related_post'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'storyyellers_sanitize_select',
    )
);
$wp_customize->add_control('number_of_footer_related_post',
    array(
        'label'       => esc_html__('Select no of post', 'storyyellers'),
        'section'     => 'homepage_footer_recomend_section',
        'choices'     => array(
            '1'          => esc_html__('1', 'storyyellers'),
            '2'          => esc_html__('2', 'storyyellers'),
            '3'          => esc_html__('3', 'storyyellers'),
            '4'          => esc_html__('4', 'storyyellers'),
            '5'          => esc_html__('5', 'storyyellers'),
            '6'          => esc_html__('6', 'storyyellers'),
            '7'          => esc_html__('7', 'storyyellers'),
            '8'          => esc_html__('8', 'storyyellers'),
            '9'          => esc_html__('9', 'storyyellers'),
        ),
        'type'     => 'select',
    )
);


// Setting - drop down category for footer related post.
$wp_customize->add_setting('select_category_for_related_post',
    array(
        'default'           => $storyyellers_default['select_category_for_related_post'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'absint',
    )
);
$wp_customize->add_control(new Storyyellers_Dropdown_Taxonomies_Control($wp_customize, 'select_category_for_related_post',
    array(
        'label'           => esc_html__('Category for related post', 'storyyellers'),
        'section'         => 'homepage_footer_recomend_section',
        'type'            => 'dropdown-taxonomies',
        'taxonomy'        => 'category',

    )));

/*Button Text*/
$wp_customize->add_setting('footer_related_post_button',
    array(
        'default'           => $storyyellers_default['footer_related_post_button'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control('footer_related_post_button',
    array(
        'label'       => esc_html__('Related Post Button Text', 'storyyellers'),
        'description' => esc_html__('Removing text will disable read more on the related post', 'storyyellers'),
        'section'     => 'homepage_footer_recomend_section',
        'type'        => 'text',
    )
);

$wp_customize->add_setting('footer_related_post_button_url',
    array(
        'default'           => $storyyellers_default['footer_related_post_button_url'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control('footer_related_post_button_url',
    array(
        'label'       => esc_html__('Related Post Button URL', 'storyyellers'),
        'section'     => 'homepage_footer_recomend_section',
        'type'        => 'text',
    )
);