<?php
/**
* Custom Functions.
*
* @package StoryYellers
*/

if( !function_exists( 'storyyellers_sanitize_sidebar_option' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_sidebar_option( $storyyellers_input ){

        $storyyellers_metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $storyyellers_input,$storyyellers_metabox_options ) ){

            return $storyyellers_input;

        }

        return;

    }

endif;

if( !function_exists( 'storyyellers_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_single_pagination_layout( $storyyellers_input ){

        $storyyellers_single_pagination = array( 'no-navigation','norma-navigation','ajax-next-post-load' );
        if( in_array( $storyyellers_input,$storyyellers_single_pagination ) ){

            return $storyyellers_input;

        }

        return;

    }

endif;

if( !function_exists( 'storyyellers_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_archive_layout( $storyyellers_input ){

        $storyyellers_archive_option = array( 'default','full','grid','masonry' );
        if( in_array( $storyyellers_input,$storyyellers_archive_option ) ){

            return $storyyellers_input;

        }

        return;

    }

endif;

if( !function_exists( 'storyyellers_sanitize_header_layout' ) ) :

    // Sidebar Option Sanitize.
    function storyyellers_sanitize_header_layout( $storyyellers_input ){

        $storyyellers_header_options = array( 'layout-1','layout-2','layout-3' );
        if( in_array( $storyyellers_input,$storyyellers_header_options ) ){

            return $storyyellers_input;

        }

        return;

    }

endif;

if( !function_exists( 'storyyellers_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function storyyellers_sanitize_single_post_layout( $storyyellers_input ){

        $storyyellers_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $storyyellers_input,$storyyellers_single_layout ) ){

            return $storyyellers_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'storyyellers_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function storyyellers_sanitize_checkbox( $storyyellers_checked ) {

		return ( ( isset( $storyyellers_checked ) && true === $storyyellers_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'storyyellers_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function storyyellers_sanitize_select( $storyyellers_input, $storyyellers_setting ) {

        // Ensure input is a slug.
        $storyyellers_input = sanitize_text_field( $storyyellers_input );

        // Get list of choices from the control associated with the setting.
        $choices = $storyyellers_setting->manager->get_control( $storyyellers_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $storyyellers_input, $choices ) ? $storyyellers_input : $storyyellers_setting->default );

    }

endif;

if ( ! function_exists( 'storyyellers_sanitize_repeater' ) ) :
    
    /**
    * Sanitise Repeater Field
    */
    function storyyellers_sanitize_repeater($input){
        $input_decoded = json_decode( $input, true );
        
        if(!empty($input_decoded)) {

            foreach ($input_decoded as $boxes => $box ){

                foreach ($box as $key => $value){

                    if( $key == 'category_color' ){

                        $input_decoded[$boxes][$key] = sanitize_hex_color( $value );

                    }else{

                        $input_decoded[$boxes][$key] = sanitize_text_field( $value );

                    }
                    
                }

            }
           
            return json_encode($input_decoded);

        }

        return $input;
    }
endif;

if ( ! function_exists( 'storyyellers_sanitize_dropdown_pages' ) ) :

    /**
     * Sanitize dropdown pages.
     *
     * @since 1.0.0
     *
     * @param int                  $page_id Page ID.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int|string Page ID if the page is published; otherwise, the setting default.
     */
    function storyyellers_sanitize_dropdown_pages( $page_id, $setting ) {

        // Ensure $input is an absolute integer.
        $page_id = absint( $page_id );

        // If $page_id is an ID of a published page, return it; otherwise, return the default.
        return ( 'publish' === get_post_status( $page_id ) ? $page_id : $setting->default );

    }

endif;


if ( ! function_exists( 'storyyellers_sanitize_image' ) ) :

    /**
     * Sanitize image.
     *
     * @since 1.0.0
     *
     * @see wp_check_filetype() https://developer.wordpress.org/reference/functions/wp_check_filetype/
     *
     * @param string               $image Image filename.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return string The image filename if the extension is allowed; otherwise, the setting default.
     */
    function storyyellers_sanitize_image( $image, $setting ) {

        /**
         * Array of valid image file types.
         *
         * The array includes image mime types that are included in wp_get_mime_types().
        */
        $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        );

        // Return an array with file extension and mime_type.
        $file = wp_check_filetype( $image, $mimes );

        // If $image has a valid mime_type, return it; otherwise, return the default.
        return ( $file['ext'] ? $image : $setting->default );

    }

endif;


/*callback section*/
if ( ! function_exists( 'storyyellers_transparent_logo_upload' ) ) :

    /**
     * Check if slider section page/post is active.
     *
     * @since 1.0.0
     *
     * @param WP_Customize_Control $control WP_Customize_Control instance.
     *
     * @return bool Whether the control is active to the current preview.
     */
    function storyyellers_transparent_logo_upload( $control ) {

        if ( 1 == $control->manager->get_setting( 'ed_transparent_menu' )->value() ) {
            return true;
        } else {
            return false;
        }

    }

endif;
